aboutsummaryrefslogtreecommitdiffstats
path: root/src/menu/frame_background.hpp
diff options
context:
space:
mode:
authorAlexander Sulfrian <alexander@sulfrian.net>2010-04-20 15:28:17 +0200
committerAlexander Sulfrian <alexander@sulfrian.net>2013-01-05 17:17:47 +0100
commitf2b29d039424262426fd4598ce076f54e31854cf (patch)
tree86b6a67c0f41722e0cb4776b11ff580709333ded /src/menu/frame_background.hpp
parent453785055b37a84d64c344f2175874bdb9e1563e (diff)
downloadusdx-f2b29d039424262426fd4598ce076f54e31854cf.tar.gz
usdx-f2b29d039424262426fd4598ce076f54e31854cf.tar.xz
usdx-f2b29d039424262426fd4598ce076f54e31854cf.zip
started gui framework
renamed menubackground to framebackground and splited out framebackgroundcolor created control as base class renamed draw to repaint and on_draw to draw in drawable implemented drawablecontrol as base for all visible controls on windows created container (subclass of drawablecontrol) that could contain other drawablecontrols created frame (subclass of container) with a background added openGL ldflag
Diffstat (limited to '')
-rw-r--r--src/menu/frame_background.hpp (renamed from src/menu/menuBackground.hpp)35
1 files changed, 12 insertions, 23 deletions
diff --git a/src/menu/menuBackground.hpp b/src/menu/frame_background.hpp
index c398b381..e815094a 100644
--- a/src/menu/menuBackground.hpp
+++ b/src/menu/frame_background.hpp
@@ -24,45 +24,34 @@
* $Id$
*/
-#ifndef MENUBACKGROUND_HPP
-#define MENUBACKGROUND_HPP
+#ifndef FRAME_BACKGROUND_HPP
+#define FRAME_BACKGROUND_HPP
+
+#include "drawable.hpp"
namespace usdx
{
// Exception
- class MenuBackgroundException { };
+ class FrameBackgroundException { };
- // MenuBackground - abstract class for MenuBackgrounds
- class MenuBackground
+ // FrameBackground - abstract class for FrameBackgrounds
+ class FrameBackground : public Drawable
{
public:
- virtual void draw(void) = 0;
+ FrameBackground();
// optional methods
- virtual ~MenuBackground() {}
+ virtual ~FrameBackground();
virtual void on_show(void) {}
virtual void on_finish(void) {}
protected:
// no copy and no assignment
- MenuBackground(const MenuBackground&);
- MenuBackground& operator=(const MenuBackground&);
- };
-
- class MenuBackgroundNone : MenuBackground
- {
- public:
- virtual void draw(void);
- };
+ FrameBackground(const FrameBackground&);
+ FrameBackground& operator=(const FrameBackground&);
- class MenuBackgroundColor : MenuBackground
- {
- private:
- RGB color;
- public:
- MenuBackgroundColor(RGB &color);
- virtual void draw(void);
+ virtual void draw(void) = 0;
};
};